@@ -7,7 +7,7 @@ use utf8;
 use Log::Any qw($log);
 use Carp;
 
-use constant VERSION => '1.0.0';
+use constant VERSION => '1.01';
 
 # class/static variables
 our $api_client;
@@ -18,5 +18,5 @@ our $debug = 0;
 # authenticaiton setting
 our $app_sid;
 our $api_key;
-our $api_server = 'http://api.aspose.com/v1.1';
+our $api_server = 'http://api.aspose.cloud/v1.1';
 1;
